﻿''
'' WpfVB
''
'' Copyright (c) 2016 http://www.curict.com
'' This software is released under the MIT License, see LICENSE.txt.
''

Imports System.ComponentModel

Public Class MainWindowViewModel : Implements INotifyDataErrorInfo

    Private _errorMessageDict As New Dictionary(Of String, String)
    Private _text1 As String
    Private _text2 As String


    Public Sub New()
        Me.Text1 = String.Empty
        Me.Text2 = String.Empty
    End Sub


    Public Property Text1 As String
        Get
            Return _text1
        End Get
        Set(value As String)
            _text1 = value
            If String.IsNullOrEmpty(_text1) Then
                _errorMessageDict("Text1") = "テキストボックスが空です。"
                RaiseEvent ErrorsChanged(Me, New DataErrorsChangedEventArgs("Text1"))
            Else
                _errorMessageDict("Text1") = String.Empty
                RaiseEvent ErrorsChanged(Me, New DataErrorsChangedEventArgs("Text1"))
            End If
        End Set
    End Property

    Public Property Text2 As String
        Get
            Return _text2
        End Get
        Set(value As String)
            _text2 = value
            If String.IsNullOrEmpty(_text2) Then
                _errorMessageDict("Text2") = "テキストボックスが空です。"
                RaiseEvent ErrorsChanged(Me, New DataErrorsChangedEventArgs("Text2"))
            Else
                _errorMessageDict("Text2") = String.Empty
                RaiseEvent ErrorsChanged(Me, New DataErrorsChangedEventArgs("Text2"))
            End If
        End Set
    End Property




    Public ReadOnly Property HasErrors As Boolean Implements INotifyDataErrorInfo.HasErrors
        Get
            For Each pair As KeyValuePair(Of String, String) In _errorMessageDict
                If Not String.IsNullOrEmpty(pair.Value) Then
                    Return True
                End If
            Next
            Return False
        End Get
    End Property

    Public Event ErrorsChanged As EventHandler(Of DataErrorsChangedEventArgs) Implements INotifyDataErrorInfo.ErrorsChanged

    Public Function GetErrors(propertyName As String) As IEnumerable Implements INotifyDataErrorInfo.GetErrors
        If Not _errorMessageDict.ContainsKey(propertyName) Then
            Return Nothing
        End If

        ' 指定されたプロパティで発生しているエラーメッセージを取得
        Dim errorMessage As String = _errorMessageDict(propertyName)

        If String.IsNullOrEmpty(errorMessage) Then
            ' エラーが無いときは空の文字列ではなく、Nothingを返す
            ' Return Nothingの行を消すとエラーが戻らなくなる
            Return Nothing
        End If

        ' エラーメッセージを返す
        Return New String() {errorMessage}
    End Function
End Class
